@@ -21,11 +21,8 @@ Usage::
     describe_scaling_plans_paginator: DescribeScalingPlansPaginator = client.get_paginator("describe_scaling_plans")
     ```
 """
-from mypy_boto3_autoscaling_plans.client import AutoScalingPlansClient
-from mypy_boto3_autoscaling_plans.paginator import (
-    DescribeScalingPlanResourcesPaginator,
-    DescribeScalingPlansPaginator,
-)
+from .client import AutoScalingPlansClient
+from .paginator import DescribeScalingPlanResourcesPaginator, DescribeScalingPlansPaginator
 
 Client = AutoScalingPlansClient
 
